body {
  background: #000040;
}
pre {
  color: white;
  height: 100%;
  font-variant-ligatures: none;
  white-space: pre-wrap;
  word-break: break-all;
  overflow-y: scroll;
  scrollbar-width: none;
  -ms-overflow-style: none;
}
pre::-webkit-scrollbar {
  width: 0;
  height: 0;
}
